@@ -17,23 +17,16 @@ class TemplateError(Exception):
 
     Attributes:
 
-    ``message``
+    ``msg``
         explanation of what the specific error is.
     """
-    def __init__(self, message):
-        self.message = message
+    def __init__(self, msg):
+        self.msg = msg
 
     def __str__(self):
-        return self.message
+        return self.msg
 
-# Tidy import 
 
-try:
-    import tidy as tidylib
-except ImportError:
-    tidy_available = False
-else:
-    tidy_available = True
 
 class DreamweaverTemplateInstance(object):
     """\
@@ -146,44 +139,6 @@ class DreamweaverTemplateInstance(object):
             ]
         )
 
-    def get(self, key):
-        """\
-        Return the current value of the editable region ``key``.
-        """
-        # Should this return a copy?
-        if self.page_regions.has_key(key):
-            return self.page_regions[key]
-        else:
-            raise TemplateError(
-                "Error, %r is not an editable region the template." % key
-            )
-    
-    def set(self, key, value):
-        """\
-        Set the editable region specified by ``key`` to ``value``.
-        """
-        if not isinstance(value, unicode):
-            value = value.decode('utf=8')
-        if not isinstance(key, unicode):
-            key = key.decode('utf-8')
-        if self.page_regions.has_key(key):
-            self.page_regions[key] = value
-            if key not in self.updated_regions:
-                self.updated_regions.append(key)
-        else:
-            raise TemplateError(
-                "Error, '%s' is not an editable region of the template." % key
-            )
-        
-    def append(self, key, value):
-        """\
-        Append ``value`` to the end of the editable region specified by 
-        ``key``.
-        """
-        value = unicode(value)
-        key = unicode(key)
-        self.set(key, self.get(key)+value)
-        
     def save_as_page(
         self, 
         filename=None, 
@@ -212,11 +167,11 @@ class DreamweaverTemplateInstance(object):
                         "Please specify 'old_path', the full path and "
                         "filename the page was loaded from."
                     )
-            if not new_path:
+            if new_path is None:
                 # Assume we want to save it to the filename specified or back
                 # to where it came from as a last resort
                 new_path = filename or self.filename
-                if not new_path:
+                if new_path is None:
                     raise TemplateError(
                         "Please specify 'new_path', the full path and "
                         "filename the page should be saved to."
@@ -245,9 +200,9 @@ class DreamweaverTemplateInstance(object):
                         "filename of the original template"
                     )
             old_path = template_path
-            if not new_path:
+            if new_path is None:
                 new_path = filename
-                if not filename:
+                if filename is None:
                     raise TemplateError(
                         "Please specify 'new_path', the full path and "
                         "filename of the new page to be created"
@@ -273,7 +228,7 @@ class DreamweaverTemplateInstance(object):
                     # is using
                     pos = end_of_start_html_tag(template_region)
                     rel = relpath(
-                        self.template_path, 
+                        template_path, 
                         posixpath.dirname(new_path)
                     )
                     template_region = '%s%s%s' % (
@@ -356,7 +311,7 @@ class DreamweaverTemplateInstance(object):
                             'comment specifying the template location'
                         )
                     rel = relpath(
-                        self.template_path, 
+                        template_path, 
                         posixpath.dirname(new_path)
                     )
                     page_region = '%s%s%s' % (
@@ -453,7 +408,47 @@ class DreamweaverTemplateInstance(object):
         Simulate mapping-style access.
         """
         self.set(key, value)
+
+    def get(self, key):
+        """\
+        Return the current value of the editable region ``key``.
+        """
+        # Should this return a copy?
+        if self.page_regions.has_key(key):
+            return self.page_regions[key]
+        else:
+            raise TemplateError(
+                "Error, %r is not an editable region the template." % key
+            )
     
+    def set(self, key, value):
+        """\
+        Set the editable region specified by ``key`` to ``value``.
+        """
+        if not isinstance(value, unicode):
+            value = value.decode('utf=8')
+        if not isinstance(key, unicode):
+            key = key.decode('utf-8')
+        if self.page_regions.has_key(key):
+            self.page_regions[key] = value
+            if key not in self.updated_regions:
+                self.updated_regions.append(key)
+        else:
+            raise TemplateError(
+                "Error, '%s' is not an editable region of the template%s" % (
+                    key, self.filename and ' '+self.filename or ''
+                )
+            )
+        
+    def append(self, key, value):
+        """\
+        Append ``value`` to the end of the editable region specified by 
+        ``key``.
+        """
+        value = unicode(value)
+        key = unicode(key)
+        self.set(key, self.get(key)+value)
+
     # Simulated methods
     
     def keys(self):
@@ -477,6 +472,7 @@ class DreamweaverTemplateInstance(object):
         keys.
         """
         return self.page_regions.copy()
+
 DWT = DreamweaverTemplateInstance
 
 # Helpers
@@ -535,9 +531,16 @@ def start_of_end_html_tag(template, filename=None):
     return end_html_match.start(0)
  
 def tidy_output(output):
+    # Tidy import 
+    try:
+        import tidylib
+    except ImportError:
+        tidy_available = False
+    else:
+        tidy_available = True
     if not tidy_available:
         raise TemplateError(
-            "The 'tidy' module from uTidyLib is not available"
+            "The 'tidy' module from 'pytidylib' is not available"
         )
     options = dict(
         output_xhtml=1, 
@@ -546,7 +549,7 @@ def tidy_output(output):
         tidy_mark=0,
         wrap=78,
     )
-    output = tidylib.parseString(output.encode('utf-8'), **options)
+    output, errors = tidylib.tidy_document(output.encode('utf-8'), options)
     return output
 
 # Link functions
@@ -556,8 +559,13 @@ href_and_src_pattern = \
 
 def update_links(site_root, old_path, new_path, content):
     site_root = uniform_path(site_root)
+    add_new_path_slash = False
+    if new_path.endswith('/'):
+        add_new_path_slash = True
     old_path = uniform_path(old_path)
     new_path = uniform_path(new_path)
+    if add_new_path_slash:
+        new_path += '/'
     # First check old_path and new_path are under site root
     if not old_path.startswith(site_root):
         raise TemplateError(
